package
Version:
v0.0.0-...-c95f17e
Opens a new window with list of versions in this module.
Published: Nov 23, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Resource struct {
ID string `json:"id"`
CreationTime time.Time `json:"CreationTime,omitempty"`
LastChange time.Time `json:"LastChange,omitempty"`
RelatedResources []string `json:"RelatedResources,omitempty"`
Risk []string `json:"Riks"`
Tags []string `json:"Tags"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.